@@ -395,6 +395,16 @@ impl<W> JsonObjectKeyEncoder<W> {
     }
 }
 
+macro_rules! format_integer {
+    ($slf:ident, $value:ident) => {{
+        $slf.writer.write_byte(b'"')?;
+        let mut buffer = itoa::Buffer::new();
+        $slf.writer.write_bytes(buffer.format($value).as_bytes())?;
+        $slf.writer.write_byte(b'"')?;
+        Ok(())
+    }};
+}
+
 impl<W> Encoder for JsonObjectKeyEncoder<W>
 where
     W: Writer,
@@ -415,21 +425,63 @@ where
     }
 
     #[inline]
-    fn encode_usize(mut self, value: usize) -> Result<Self::Ok, Self::Error> {
-        self.writer.write_byte(b'"')?;
-        let mut buffer = itoa::Buffer::new();
-        self.writer.write_bytes(buffer.format(value).as_bytes())?;
-        self.writer.write_byte(b'"')?;
-        Ok(())
+    fn encode_u8(mut self, value: u8) -> Result<Self::Ok, Self::Error> {
+        format_integer!(self, value)
+    }
+
+    #[inline]
+    fn encode_u16(mut self, value: u16) -> Result<Self::Ok, Self::Error> {
+        format_integer!(self, value)
     }
 
     #[inline]
     fn encode_u32(mut self, value: u32) -> Result<Self::Ok, Self::Error> {
-        self.writer.write_byte(b'"')?;
-        let mut buffer = itoa::Buffer::new();
-        self.writer.write_bytes(buffer.format(value).as_bytes())?;
-        self.writer.write_byte(b'"')?;
-        Ok(())
+        format_integer!(self, value)
+    }
+
+    #[inline]
+    fn encode_u64(mut self, value: u64) -> Result<Self::Ok, Self::Error> {
+        format_integer!(self, value)
+    }
+
+    #[inline]
+    fn encode_u128(mut self, value: u128) -> Result<Self::Ok, Self::Error> {
+        format_integer!(self, value)
+    }
+
+    #[inline]
+    fn encode_i8(mut self, value: i8) -> Result<Self::Ok, Self::Error> {
+        format_integer!(self, value)
+    }
+
+    #[inline]
+    fn encode_i16(mut self, value: i16) -> Result<Self::Ok, Self::Error> {
+        format_integer!(self, value)
+    }
+
+    #[inline]
+    fn encode_i32(mut self, value: i32) -> Result<Self::Ok, Self::Error> {
+        format_integer!(self, value)
+    }
+
+    #[inline]
+    fn encode_i64(mut self, value: i64) -> Result<Self::Ok, Self::Error> {
+        format_integer!(self, value)
+    }
+
+    #[inline]
+    fn encode_i128(mut self, value: i128) -> Result<Self::Ok, Self::Error> {
+        format_integer!(self, value)
+    }
+
+    #[inline]
+    fn encode_usize(mut self, value: usize) -> Result<Self::Ok, Self::Error> {
+        format_integer!(self, value)
+    }
+
+    #[inline]
+    fn encode_isize(mut self, value: isize) -> Result<Self::Ok, Self::Error> {
+        format_integer!(self, value)
     }
 
     #[inline]
