@@ -192,7 +192,7 @@ where
     where
         T: ?Sized + Encode<M>,
     {
-        let mut data = Vec::new();
+        let mut data = Vec::with_capacity(128);
         T::encode(value, JsonEncoder::<M, _>::new(&mut data))?;
         Ok(data)
     }
@@ -204,7 +204,7 @@ where
     where
         T: ?Sized + Encode<M>,
     {
-        let mut data = Vec::new();
+        let mut data = Vec::with_capacity(128);
         T::encode(value, JsonEncoder::<M, _>::new(&mut data))?;
         // SAFETY: Encoder is guaranteed to produce valid UTF-8.
         Ok(unsafe { String::from_utf8_unchecked(data) })
