@@ -1,4 +1,6 @@
-use crate::reader::{string, ParseError, ParseErrorKind, Scratch, StringReference, Token};
+use musli::de::NumberVisitor;
+
+use crate::reader::{integer, string, ParseError, ParseErrorKind, Scratch, StringReference, Token};
 
 mod private {
     pub trait Sealed {}
@@ -127,6 +129,78 @@ pub trait Parser<'de>: private::Sealed {
 
         Ok(())
     }
+
+    /// Parse an unknown number and try to coerce it into the best fit type
+    /// through [NumberVisitor].
+    #[doc(hidden)]
+    fn parse_number<V>(&mut self, visitor: V) -> Result<V::Ok, ParseError>
+    where
+        V: NumberVisitor<Error = ParseError>,
+    {
+        let signed = integer::decode_signed::<i128, _>(self)?;
+
+        if signed.is_negative {
+            let value = match signed.compute() {
+                Ok(value) => value,
+                Err(..) => {
+                    let value = signed.compute_float();
+                    return visitor.visit_f64(value);
+                }
+            };
+
+            if value >= i8::MIN as i128 && value <= i8::MAX as i128 {
+                return visitor.visit_i8(value as i8);
+            }
+
+            if value >= i16::MAX as i128 && value <= i16::MAX as i128 {
+                return visitor.visit_i16(value as i16);
+            }
+
+            if value >= i32::MAX as i128 && value <= i32::MAX as i128 {
+                return visitor.visit_i32(value as i32);
+            }
+
+            if value >= i64::MAX as i128 && value <= i64::MAX as i128 {
+                return visitor.visit_i64(value as i64);
+            }
+
+            if value >= isize::MAX as i128 && value <= isize::MAX as i128 {
+                return visitor.visit_isize(value as isize);
+            }
+
+            visitor.visit_i128(value)
+        } else {
+            let value = match signed.unsigned.compute() {
+                Ok(value) => value,
+                Err(..) => {
+                    let value = signed.unsigned.compute_float();
+                    return visitor.visit_f64(value);
+                }
+            };
+
+            if value <= u8::MAX as u128 {
+                return visitor.visit_u8(value as u8);
+            }
+
+            if value <= u16::MAX as u128 {
+                return visitor.visit_u16(value as u16);
+            }
+
+            if value <= u32::MAX as u128 {
+                return visitor.visit_u32(value as u32);
+            }
+
+            if value <= u64::MAX as u128 {
+                return visitor.visit_u64(value as u64);
+            }
+
+            if value <= usize::MAX as u128 {
+                return visitor.visit_usize(value as usize);
+            }
+
+            visitor.visit_u128(value)
+        }
+    }
 }
 
 impl<'de, P> Parser<'de> for &mut P
